@@ -23,4 +23,16 @@ BOOL WINAPI RaiseExceptionCheck(BOOL bSuccess) {
         return TRUE;
     }
     return FALSE;
+}
+
+BOOL WINAPI ExceptionCheckHRESULT(HRESULT res) {
+    if (res == S_OK) return FALSE;
+    PyErr_SetFromWindowsErr(HRESULT_CODE(res));
+    return TRUE;
+}
+
+BOOL WINAPI RaiseExceptionCheckInvalid(BOOL bSuccess) {
+    if (bSuccess) return FALSE;
+    PyErr_SetFromWindowsErr(87);
+    return TRUE;
 }
\ No newline at end of file
